==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/integration-tests/it-producer/src/main/java/org/apache/servicecomb/it/schema/DefaultJsonValueJaxrsSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.it.schema;

import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.QueryParam;

import org.apache.servicecomb.provider.rest.common.RestSchema;

@RestSchema(schemaId = "defaultJsonValueJaxrs")
@Path("/v1/defaultJsonValueJaxrs")
public class DefaultJsonValueJaxrsSchema {
  @Path("jsonInput")
  @POST
  public DefaultJsonValueResponse jsonInput(DefaultJsonValueRequest request) {
    DefaultJsonValueResponse response = new DefaultJsonValueResponse();
    response.setType(request.getType());
    StringBuilder sb = new StringBuilder();
    sb.append(request.getDefaultValue());
    response.setMessage("expected:" + sb.toString() + ":" + (request.getItems() == null ? null
        : request.getItems().size()));
    return response;
  }

  @Path("queryInput")
  @GET
  public String queryInput(HttpServletRequest request, @QueryParam("size") int size) {
    return "expected:" + size + ":" + request.getParameter("size");
  }
}

==> apache-servicecomb-java-chassis-distribution-2.7.6-src.zip: apache-servicecomb-java-chassis-distribution-2.7.6-src/integration-tests/it-producer/src/main/java/org/apache/servicecomb/it/schema/DefaultJsonValueJaxrsSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.it.schema;

import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.QueryParam;

import org.apache.servicecomb.provider.rest.common.RestSchema;

@RestSchema(schemaId = "defaultJsonValueJaxrs")
@Path("/v1/defaultJsonValueJaxrs")
public class DefaultJsonValueJaxrsSchema {
  @Path("jsonInput")
  @POST
  public DefaultJsonValueResponse jsonInput(DefaultJsonValueRequest request) {
    DefaultJsonValueResponse response = new DefaultJsonValueResponse();
    response.setType(request.getType());
    StringBuilder sb = new StringBuilder();
    sb.append(request.getDefaultValue());
    response.setMessage("expected:" + sb + ":" + (request.getItems() == null ? null
        : request.getItems().size()));
    return response;
  }

  @Path("queryInput")
  @GET
  public String queryInput(HttpServletRequest request, @QueryParam("size") int size) {
    return "expected:" + size + ":" + request.getParameter("size");
  }
}
